@@ -3,7 +3,7 @@ package X::Tiny;
 use strict;
 use warnings;
 
-our $VERSION = '0.21_90';
+our $VERSION = '0.01';
 
 =encoding utf-8
 
@@ -38,7 +38,7 @@ X::Tiny - Base class for a bare-bones exception factory
     sub _new {
         my ($class, @args) = @_;
 
-        my $self = $class->SUPER::_new('Blah blah', @args);
+        my $self = $class->SUPER::_new('Blah blah, @args);
 
         return bless $self, $class;
     }
@@ -56,8 +56,6 @@ X::Tiny - Base class for a bare-bones exception factory
         print $err->get('key1');
     }
 
-    die My::Module::X->create('Blah', key1 => val1, … );
-
 =head1 DESCRIPTION
 
 This stripped-down exception framework provides a baseline
@@ -74,7 +72,7 @@ failures: if you’re given a set of instructions, and something goes wrong
 in one of those instructions, it makes sense to stop and go back to see what
 to do in response to the problem.
 
-Perl’s built-ins unwisely make the caller responsible for error checking—as
+Perl’s built-ins unwisely make the caller responsibile for error checking—as
 a result of which much Perl code fails to check for failures from those
 built-ins, which makes for far more difficult debugging when some code down
 the line just mysteriously produces an unexpected result.
@@ -86,12 +84,7 @@ exception objects whose type and attributes can facilitate meaningful
 error checking; for example, you may not care if a call to C<unlink()> fails
 with C<ENOENT>, so you can just ignore that failure. Or, you might care, but
 you might prefer just to C<warn()> rather than to stop what you’re doing.
-
-X::Tiny is one of many CPAN modules that facilitates this pattern. What
-separates X::Tiny from other such modules is its light weight: the only
-“heavy” dependency is L<overload>, which is (in my experience) a reasonable
-trade-off for the helpfulness of having stack traces on uncaught exceptions.
-(The stack trace is custom logic, much lighter than L<Carp>.)
+That’s where C<X::Tiny> comes in.
 
 =head1 FEATURES
 
@@ -135,27 +128,26 @@ with the arguments C<foo> and C<bar>.
 
 =head1 EXCEPTION OBJECTS
 
-See L<X::Tiny::Base> for more information about the features that that
+See C<X::Tiny::Base> for more information about the features that that
 module exposes to subclasses.
 
 =head1 DESIGN CONSIDERATIONS
 
 Admittedly, the lazy-loading behavior here embodies a generally-unwise
-practice of doing failure-prone work (i.e., loading a module at runtime)
-in the process of reporting a failure.
+practice of doing failure-prone work in the process of reporting a failure.
 In my own experience, though, that’s a reasonable tradeoff for the
 expressiveness of typed exceptions.
 
 Do be sure that any failure-prone work you do as part of exception
 instantiation has its own failure-checking mechanism. There really are not
-meant to be “sub-failures” here!
+meant to be “sub-failures” here.
 
 =cut
 
 use strict;
 use warnings;
 
-use Module::Runtime ();
+use Module::Load ();
 
 sub create {
     my ( $class, $type, @args ) = @_;
@@ -163,7 +155,7 @@ sub create {
     my $x_package = "${class}::$type";
 
     if (!$x_package->can('new')) {
-        Module::Runtime::require_module($x_package);
+        Module::Load::load($x_package);
     }
 
     return $x_package->new(@args);
@@ -175,16 +167,12 @@ sub create {
 
 =head1 REPOSITORY
 
-L<https://github.com/FGasper/p5-X-Tiny>
+https://github.com/FGasper/p5-X-Tiny
 
 =head1 AUTHOR
 
 Felipe Gasper (FELIPE)
 
-=head1 COPYRIGHT
-
-Copyright 2017-2019 by L<Gasper Software Consulting|http://gaspersoftware.com>
-
 =head1 LICENSE
 
-This distribution is released under the same license as Perl.
+This distribution is released under the license as Perl.
