@@ -25,17 +25,12 @@ X::Tiny::Base - super-light exception base class
         ...
     }
 
-    #Optionally, redefine this:
     sub get {
         my ($self, $attr_name) = @_;
 
         ...
     }
 
-    #Optionally, redefine this:
-    sub get_message { ... }
-
-    #Optionally, redefine this:
     sub to_string { ... }
 
     #If you override this, be sure also to call the base method.
@@ -50,11 +45,12 @@ X::Tiny::Base - super-light exception base class
 
 =head1 DESCRIPTION
 
-This base class can be subclassed into your distribution’s own
-exception base class (e.g., C<My::Module::X::Base>), or you can treat it
-as that base class itself (i.e., forgo C<My::Module::X::Base>).
+This base class is meant for you to subclass into your distribution’s own
+exception base class (e.g., C<My::Module::X::Base>); you should then
+subclass that base class for your distribution’s specific exception classes
+(e.g., C<My::Module::X::BadInput>).
 
-C<X::Tiny::Base> serves two functions:
+C<X::Tiny::Base>, then, serves two functions:
 
 =over
 
@@ -66,18 +62,11 @@ e.g., when an uncaught exception is printed.
 =back
 
 That stringification’s precise formatting is not defined; however, it
-will always include, in addition to the exception’s main message:
+will always include:
 
 =over
 
-=item * A stack trace (including function arguments)
-
-B<IMPORTANT:> For security purposes, take care not to expose any function
-arguments that might contain sensitive information (e.g., passwords).
-
-Note that, in pre-5.16 Perls, this writes to the C<@DB::args> global.
-(That shouldn’t affect you, but it’s interaction with the environment, so
-better documented than not.)
+=item * A stack trace
 
 =item * Propagations
 
@@ -129,18 +118,6 @@ sub _new {
     return bless [ $string, \%attrs ], $class;
 }
 
-=head2 I<OBJ>->get_message()
-
-Return the exception’s main MESSAGE.
-This is useful for contexts where you want to encapsulate the error
-internals from how you’re reporting them, e.g., for protocols.
-
-=cut
-
-sub get_message {
-    return $_[0][0];
-}
-
 =head2 I<OBJ>->get( ATTRIBUTE_NAME )
 
 Retrieves the value of an attribute.
@@ -198,7 +175,7 @@ sub new {
 
     my $self = $class->_new(@args);
 
-    $CALL_STACK{$self->_get_strval()} = [ _get_printable_call_stack(2) ];
+    $CALL_STACK{$self->_get_strval()} = [ _get_call_stack(2) ];
 
     return $self;
 }
@@ -223,12 +200,7 @@ sub _check_overload {
 
     $_OVERLOADED{$class} ||= eval qq{
         package $class;
-
-        use overload (
-            q<""> => __PACKAGE__->can('__spew'),
-            bool => __PACKAGE__->can('_TRUE'),
-        );
-
+        use overload (q<""> => __PACKAGE__->can('__spew'));
         1;
     };
 
@@ -250,21 +222,15 @@ sub _get_strval {
     return q<> . $self;
 }
 
-sub _get_printable_call_stack {
+sub _get_call_stack {
     my ($level) = @_;
 
     my @stack;
 
-    package DB;
-
-    #This local() causes pre-5.16 Perl to segfault.
-    local @DB::args if $^V ge v5.16.0;
-
     while ( my @call = (caller $level)[3, 1, 2] ) {
         my ($pkg) = ($call[0] =~ m<(.+)::>);
 
         if (!$pkg || !$pkg->isa(__PACKAGE__)) {
-            push @call, [ map { X::Tiny::Base::_arg_to_printable() } @DB::args ];  #need to copy the array
             push @stack, \@call;
         }
 
@@ -274,30 +240,13 @@ sub _get_printable_call_stack {
     return @stack;
 }
 
-sub _arg_to_printable {
-
-    # Oof. In order to avoid warn()ing on undefined values
-    # (and to distinguish '' from undef) we now quote scalars.
-    ref() ? "$_" : !defined() ? 'undef' : do {
-        my $copy = $_;
-        $copy =~ s<'><\\'>g;
-        "'$copy'";
-    };
-}
-
-use constant _TRUE => 1;
-
 sub __spew {
     my ($self) = @_;
 
     my $spew = $self->to_string();
 
     if ( rindex($spew, $/) != (length($spew) - length($/)) ) {
-        my ($args);
-        $spew .= $/ . join( q<>, map {
-            $args = join(', ', @{ $_->[3] } );
-            "\t==> $_->[0]($args) (called in $_->[1] at line $_->[2])$/"
-        } @{ $CALL_STACK{$self->_get_strval()} } );
+        $spew .= $/ . join( q<>, map { "\t==> $_->[0] (called in $_->[1] at line $_->[2])$/" } @{ $CALL_STACK{$self->_get_strval()} } );
     }
 
     if ( $PROPAGATIONS{ $self->_get_strval() } ) {
